summaryrefslogtreecommitdiffstats
path: root/chrome/browser/chrome_content_browser_client.cc
diff options
context:
space:
mode:
authorjoi@chromium.org <joi@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-01-18 20:26:10 +0000
committerjoi@chromium.org <joi@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-01-18 20:26:10 +0000
commit8643e6d85c2a41d6497d5cb9b69bea9465102e96 (patch)
tree59f2ce5b54122410f6200f69bbb3144d19ed02bd /chrome/browser/chrome_content_browser_client.cc
parent16128cf279e5523eac781a97600ef7d9773aa2c5 (diff)
downloadchromium_src-8643e6d85c2a41d6497d5cb9b69bea9465102e96.zip
chromium_src-8643e6d85c2a41d6497d5cb9b69bea9465102e96.tar.gz
chromium_src-8643e6d85c2a41d6497d5cb9b69bea9465102e96.tar.bz2
Rename TabContentsView to WebContentsView and move to content/public.
Also rename TestTabContentsView to TestWebContentsView. Add content namespace to both. TBR=owners (trivial updates) BUG=98716 Review URL: http://codereview.chromium.org/9241011 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@118134 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/chrome_content_browser_client.cc')
-rw-r--r--chrome/browser/chrome_content_browser_client.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/chrome/browser/chrome_content_browser_client.cc b/chrome/browser/chrome_content_browser_client.cc
index f1196ad..15542ad3 100644
--- a/chrome/browser/chrome_content_browser_client.cc
+++ b/chrome/browser/chrome_content_browser_client.cc
@@ -77,10 +77,10 @@
#include "content/browser/ssl/ssl_cert_error_handler.h"
#include "content/browser/ssl/ssl_client_auth_handler.h"
#include "content/browser/tab_contents/tab_contents.h"
-#include "content/browser/tab_contents/tab_contents_view.h"
#include "content/browser/worker_host/worker_process_host.h"
#include "content/public/browser/browser_main_parts.h"
#include "content/public/browser/render_process_host.h"
+#include "content/public/browser/web_contents_view.h"
#include "grit/generated_resources.h"
#include "grit/ui_resources.h"
#include "net/base/cookie_monster.h"
@@ -306,7 +306,7 @@ content::BrowserMainParts* ChromeContentBrowserClient::CreateBrowserMainParts(
return main_parts;
}
-TabContentsView* ChromeContentBrowserClient::CreateTabContentsView(
+content::WebContentsView* ChromeContentBrowserClient::CreateWebContentsView(
WebContents* web_contents) {
#if defined(TOOLKIT_VIEWS)
return new TabContentsViewViews(web_contents);
@@ -314,9 +314,9 @@ TabContentsView* ChromeContentBrowserClient::CreateTabContentsView(
return new content::TabContentsViewGtk(web_contents,
new ChromeTabContentsViewWrapperGtk);
#elif defined(OS_MACOSX)
- return tab_contents_view_mac::CreateTabContentsView(web_contents);
+ return tab_contents_view_mac::CreateWebContentsView(web_contents);
#else
#error Need to create your platform TabContentsView here.
#endif
}
@@ -314,9 +314,9 @@ TabContentsView* ChromeContentBrowserClient::CreateTabContentsView(
#else
-#error Need to create your platform TabContentsView here.
+#error Need to create your platform WebContentsView here.
#endif
}